/*!
Pure v0.5.0
Copyright 2014 Yahoo! Inc. All rights reserved.
Licensed under the BSD License.
https://github.com/yui/pure/blob/master/LICENSE.md
*/
/*!
normalize.css v1.1.3 | MIT License | git.io/normalize
Copyright (c) Nicolas Gallagher and Jonathan Neal
*/
/*! normalize.css v1.1.3 | MIT License | git.io/normalize */.pure article,.pure aside,.pure details,.pure figcaption,.pure figure,.pure footer,.pure header,.pure hgroup,.pure main,.pure nav,.pure section,.pure summary{display:block}.pure audio,.pure canvas,.pure video{display:inline-block;*display:inline;*zoom:1}.pure audio:not([controls]){display:none;height:0}.pure [hidden]{display:none}.pure{font-size:100%;-ms-text-size-adjust:100%;-webkit-text-size-adjust:100%}.pure,.pure button,.pure input,.pure select,.pure textarea{font-family:sans-serif}.pure{margin:0}.pure a:focus{outline:thin dotted}.pure a:active,.pure a:hover{outline:0}.pure h1{font-size:2em;margin:.67em 0}.pure h2{font-size:1.5em;margin:.83em 0}.pure h3{font-size:1.17em;margin:1em 0}.pure h4{font-size:1em;margin:1.33em 0}.pure h5{font-size:.83em;margin:1.67em 0}.pure h6{font-size:.67em;margin:2.33em 0}.pure abbr[title]{border-bottom:1px dotted}.pure b,.pure strong{font-weight:700}.pure blockquote{margin:1em 40px}.pure dfn{font-style:italic}.pure hr{-moz-box-sizing:content-box;box-sizing:content-box;height:0}.pure mark{background:#ff0;color:#000}.pure p,.pure pre{margin:1em 0}.pure code,.pure kbd,.pure pre,.pure samp{font-family:monospace,serif;_font-family:'courier new',monospace;font-size:1em}.pure pre{white-space:pre;white-space:pre-wrap;word-wrap:break-word}.pure q{quotes:none}.pure q:before,.pure q:after{content:'';content:none}.pure small{font-size:80%}.pure sub,.pure sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}.pure sup{top:-.5em}.pure sub{bottom:-.25em}.pure dl,.pure menu,.pure ol,.pure ul{margin:1em 0}.pure dd{margin:0 0 0 40px}.pure menu,.pure ol,.pure ul{padding:0 0 0 40px}.pure nav ul,.pure nav ol{list-style:none;list-style-image:none}.pure img{border:0;-ms-interpolation-mode:bicubic}.pure svg:not(:root){overflow:hidden}.pure figure{margin:0}.pure form{margin:0}.pure fieldset{border:1px solid silver;margin:0 2px;padding:.35em .625em .75em}.pure legend{border:0;padding:0;white-space:normal;*margin-left:-7px}.pure button,.pure input,.pure select,.pure textarea{font-size:100%;margin:0;vertical-align:baseline;*vertical-align:middle}.pure button,.pure input{line-height:normal}.pure button,.pure select{text-transform:none}.pure button,.pure input[type=button],.pure input[type=reset],.pure input[type=submit]{-webkit-appearance:button;cursor:pointer;*overflow:visible}.pure button[disabled],.pure input[disabled]{cursor:default}.pure input[type=checkbox],.pure input[type=radio]{box-sizing:border-box;padding:0;*height:13px;*width:13px}.pure input[type=search]{-webkit-appearance:textfield;-moz-box-sizing:content-box;-webkit-box-sizing:content-box;box-sizing:content-box}.pure input[type=search]::-webkit-search-cancel-button,.pure input[type=search]::-webkit-search-decoration{-webkit-appearance:none}.pure button::-moz-focus-inner,.pure input::-moz-focus-inner{border:0;padding:0}.pure textarea{overflow:auto;vertical-align:top}.pure table{border-collapse:collapse;border-spacing:0}.pure [hidden]{display:none!important}.pure .pure-img{max-width:100%;height:auto;display:block}