from __future__ import unicode_literals


class OCRError(Exception):
    """
    Raised by the OCR backend
    """
    pass


class UnpaperError(Exception):
    """
    Raised by unpaper
    """
    pass
