from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _

events_list = {'text': _('Events'), 'view': 'events:events_list', 'famfam': 'book', 'icon': 'main/icons/book.png'}
