from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _

link_api = {'text': _('REST API'), 'view': 'api-root', 'famfam': 'disconnect', 'icon': 'main/icons/disconnect.png'}
link_api_documentation = {'text': _('REST API Documentation'), 'view': 'django.swagger.base.view', 'famfam': 'book', 'icon': 'main/icons/book.png'}
