<div class="content">
    <h2 class="title">
        {{ title }}
    </h2>
</div>

<div class="pure-g tc">
    {% with 'navigation/large_button_link.html' as link_template %}
        {% include 'generic_navigation.html' %}
    {% endwith %}
</div>
