from __future__ import unicode_literals

__title__ = 'Mayan EDMS'
__version__ = '1.1.1'
__build__ = 0x010101
__author__ = 'Roberto Rosario'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2011-2015 Roberto Rosario'
