/*!
Pure v0.5.0
Copyright 2014 Yahoo! Inc. All rights reserved.
Licensed under the BSD License.
https://github.com/yui/pure/blob/master/LICENSE.md
*/
/*csslint box-model:false*/
/*TODO: Remove this lint rule override after a refactor of this code.*/


.pure-paginator {

    /* `pure-g` Grid styles */
    letter-spacing: -0.31em; /* Webkit: collapse white-space between units */
    *letter-spacing: normal; /* reset IE < 8 */
    *word-spacing: -0.43em; /* IE < 8: collapse white-space between units */
    text-rendering: optimizespeed; /* Webkit: fixes text-rendering: optimizeLegibility */

    /* `pure-paginator` Specific styles */
    list-style: none;
    margin: 0;
    padding: 0;
}
.opera-only :-o-prefocus,
.pure-paginator {
    word-spacing: -0.43em;
}

/* `pure-u` Grid styles */
.pure-paginator li {
    display: inline-block;
    *display: inline; /* IE < 8: fake inline-block */
    zoom: 1;
    letter-spacing: normal;
    word-spacing: normal;
    vertical-align: top;
    text-rendering: auto;
}


.pure-paginator .pure-button {
    border-radius: 0;
    padding: 0.8em 1.4em;
    vertical-align: top;
    height: 1.1em;
}
.pure-paginator .pure-button:focus,
.pure-paginator .pure-button:active {
    outline-style: none;
}
.pure-paginator .prev,
.pure-paginator .next {
    color: #C0C1C3;
    text-shadow: 0 -1px 0 rgba(0,0,0, 0.45);
}
.pure-paginator .prev {
    border-radius: 2px 0 0 2px;
}
.pure-paginator .next {
    border-radius: 0 2px 2px 0;
}
