from __future__ import unicode_literals

from django.utils.translation import ugettext_lazy as _

search = {'text': _('Search'), 'view': 'search:search', 'famfam': 'zoom'}
search_advanced = {'text': _('Advanced search'), 'view': 'search:search_advanced', 'famfam': 'zoom_in'}
search_again = {'text': _('Search again'), 'view': 'search:search_again', 'famfam': 'arrow_undo'}
