from __future__ import absolute_import, unicode_literals

from . import *  # NOQA

DEBUG = False

# Update this accordingly;
# https://docs.djangoproject.com/en/dev/ref/settings/#allowed-hosts
ALLOWED_HOSTS = ['*']
